var indexSectionsWithContent =
{
  0: "0123456789_abcdefghijklmnopqrstuvwxyz~",
  1: "abcdefghiklmnoprstuvwxz",
  2: "v",
  3: "abcdefghijklmnopqrstuvwxz~",
  4: "_abcdefghijklmnopqrstuvwxyz",
  5: "abcdefgilmnopqrstuvw",
  6: "abcdefgijlmprstvw",
  7: "abcdefhiklmnprstuwz",
  8: "s",
  9: "01234579abcflmnstuv",
  10: "346acdefiklmnostuvwxy"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "related",
  9: "groups",
  10: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Friends",
  9: "Modules",
  10: "Pages"
};

